var searchData=
[
  ['d_0',['d',['../structDav1dSegmentationDataSet.html#a9a5f7c927df14d61f15d06cb0d359f09',1,'Dav1dSegmentationDataSet']]],
  ['damping_1',['damping',['../structDav1dFrameHeader.html#af7f944a1a64aa605447ed26f1ed30463',1,'Dav1dFrameHeader']]],
  ['data_2',['data',['../structDav1dUserData.html#abea83576f25527ba0b464d28e86f2757',1,'Dav1dUserData::data'],['../structDav1dData.html#a08e47b7276c43111369e43439f8cfe9f',1,'Dav1dData::data'],['../structDav1dFrameHeader.html#a0793ad1ee6079e66307a11c3b3bb6432',1,'Dav1dFrameHeader::data'],['../structDav1dPicture.html#ae6a2b8538d7a43aaab3f46d2198e67fa',1,'Dav1dPicture::data']]],
  ['decode_5fframe_5ftype_3',['decode_frame_type',['../structDav1dSettings.html#a54a22d80474a060f5e92a3f858780f23',1,'Dav1dSettings']]],
  ['decoder_5fbuffer_5fdelay_4',['decoder_buffer_delay',['../structDav1dSequenceHeader_1_1Dav1dSequenceHeaderOperatingParameterInfo.html#a2174e702c154799ce1f113a83d9e60b5',1,'Dav1dSequenceHeader::Dav1dSequenceHeaderOperatingParameterInfo']]],
  ['decoder_5fmodel_5finfo_5fpresent_5',['decoder_model_info_present',['../structDav1dSequenceHeader.html#a547c4f413e7a2f6ca50f556ea659eef9',1,'Dav1dSequenceHeader']]],
  ['decoder_5fmodel_5fparam_5fpresent_6',['decoder_model_param_present',['../structDav1dSequenceHeader_1_1Dav1dSequenceHeaderOperatingPoint.html#a0dcdf8ba72856b36911dce7b06f246fb',1,'Dav1dSequenceHeader::Dav1dSequenceHeaderOperatingPoint']]],
  ['delta_7',['delta',['../structDav1dWarpedMotionParams.html#a4eb152e946d0c075cec1007857f480ad',1,'Dav1dWarpedMotionParams::delta'],['../structDav1dFrameHeader.html#ac1e90b1fcfbcb834a3c9f051cd3774cf',1,'Dav1dFrameHeader::delta']]],
  ['delta_5fframe_5fid_5fn_5fbits_8',['delta_frame_id_n_bits',['../structDav1dSequenceHeader.html#a1e97efb39c4d53037161faed3cbf84ac',1,'Dav1dSequenceHeader']]],
  ['delta_5flf_5fu_9',['delta_lf_u',['../structDav1dSegmentationData.html#a4de13df0c53def4d92c96d514782da6e',1,'Dav1dSegmentationData']]],
  ['delta_5flf_5fv_10',['delta_lf_v',['../structDav1dSegmentationData.html#aa9cf9e0a5174f9fc8531013304e1d981',1,'Dav1dSegmentationData']]],
  ['delta_5flf_5fy_5fh_11',['delta_lf_y_h',['../structDav1dSegmentationData.html#a72aece922c5726b270984521c6dc17ee',1,'Dav1dSegmentationData']]],
  ['delta_5flf_5fy_5fv_12',['delta_lf_y_v',['../structDav1dSegmentationData.html#a6fbbe5378f59a6a5e5919b768271ce69',1,'Dav1dSegmentationData']]],
  ['delta_5fq_13',['delta_q',['../structDav1dSegmentationData.html#acfbfd240f5951c814523c4da8fdbd588',1,'Dav1dSegmentationData']]],
  ['disable_5fcdf_5fupdate_14',['disable_cdf_update',['../structDav1dFrameHeader.html#a129b2318f996385be46fe9981c17af79',1,'Dav1dFrameHeader']]],
  ['display_5fmodel_5finfo_5fpresent_15',['display_model_info_present',['../structDav1dSequenceHeader.html#aef0be3e10de2185de486ce5420fe746a',1,'Dav1dSequenceHeader']]],
  ['display_5fmodel_5fparam_5fpresent_16',['display_model_param_present',['../structDav1dSequenceHeader_1_1Dav1dSequenceHeaderOperatingPoint.html#a9778cf78a5530ece70c61cdec6869058',1,'Dav1dSequenceHeader::Dav1dSequenceHeaderOperatingPoint']]],
  ['dual_5ffilter_17',['dual_filter',['../structDav1dSequenceHeader.html#aef6e1a913236b2f859966e3eb7367cd2',1,'Dav1dSequenceHeader']]],
  ['duration_18',['duration',['../structDav1dDataProps.html#aedb99d78a3677949765aeeedb352e3ac',1,'Dav1dDataProps']]]
];
